@@ -41,7 +41,6 @@
 #include <fcntl.h>
 #include <gdk/gdkx.h>
 #include <glib/gi18n.h>
-#include <libnautilus-private/nautilus-desktop-background.h>
 #include <libnautilus-private/nautilus-desktop-icon-file.h>
 #include <libnautilus-private/nautilus-directory-notify.h>
 #include <libnautilus-private/nautilus-file-changes-queue.h>
@@ -76,8 +75,6 @@ struct NautilusDesktopCanvasViewDetails
 	gulong delayed_init_signal;
 	guint reload_desktop_timeout;
 	gboolean pending_rescan;
-
-	NautilusDesktopBackground *background;
 };
 
 static void     default_zoom_level_changed                        (gpointer                user_data);
@@ -234,22 +231,6 @@ desktop_canvas_view_property_filter (GdkXEvent *gdk_xevent,
 	return GDK_FILTER_CONTINUE;
 }
 
-static void
-real_begin_loading (NautilusView *object)
-{
-	NautilusCanvasContainer *canvas_container;
-	NautilusDesktopCanvasView *view;
-
-	view = NAUTILUS_DESKTOP_CANVAS_VIEW (object);
-
-	canvas_container = get_canvas_container (view);
-	if (view->details->background == NULL) {
-		view->details->background = nautilus_desktop_background_new (canvas_container);
-	}
-
-	NAUTILUS_VIEW_CLASS (nautilus_desktop_canvas_view_parent_class)->begin_loading (object);
-}
-
 static const char *
 real_get_id (NautilusView *view)
 {
@@ -287,11 +268,6 @@ nautilus_desktop_canvas_view_dispose (GObject *object)
 					      nautilus_view_update_menus,
 					      canvas_view);
 
-	if (canvas_view->details->background != NULL) {
-		g_object_unref (canvas_view->details->background);
-		canvas_view->details->background = NULL;
-	}
-
 	G_OBJECT_CLASS (nautilus_desktop_canvas_view_parent_class)->dispose (object);
 }
 
@@ -304,7 +280,6 @@ nautilus_desktop_canvas_view_class_init (NautilusDesktopCanvasViewClass *class)
 
 	G_OBJECT_CLASS (class)->dispose = nautilus_desktop_canvas_view_dispose;
 
-	vclass->begin_loading = real_begin_loading;
 	vclass->merge_menus = real_merge_menus;
 	vclass->update_menus = real_update_menus;
 	vclass->get_view_id = real_get_id;
@@ -312,76 +287,6 @@ nautilus_desktop_canvas_view_class_init (NautilusDesktopCanvasViewClass *class)
 	g_type_class_add_private (class, sizeof (NautilusDesktopCanvasViewDetails));
 }
 
-static void
-nautilus_desktop_canvas_view_handle_middle_click (NautilusCanvasContainer *canvas_container,
-						GdkEventButton *event,
-						NautilusDesktopCanvasView *desktop_canvas_view)
-{
-	XButtonEvent x_event;
-	GdkDevice *keyboard = NULL, *pointer = NULL, *cur;
-	GdkDeviceManager *manager;
-	GList *list, *l;
-
-	manager = gdk_display_get_device_manager (gtk_widget_get_display (GTK_WIDGET (canvas_container)));
-	list = gdk_device_manager_list_devices (manager, GDK_DEVICE_TYPE_MASTER);
-
-	for (l = list; l != NULL; l = l->next) {
-		cur = l->data;
-
-		if (pointer == NULL && (gdk_device_get_source (cur) == GDK_SOURCE_MOUSE)) {
-			pointer = cur;
-		}
-
-		if (keyboard == NULL && (gdk_device_get_source (cur) == GDK_SOURCE_KEYBOARD)) {
-			keyboard = cur;
-		}
-
-		if (pointer != NULL && keyboard != NULL) {
-			break;
-		}
-	}
-
-	g_list_free (list);
-
-	/* During a mouse click we have the pointer and keyboard grab.
-	 * We will send a fake event to the root window which will cause it
-	 * to try to get the grab so we need to let go ourselves.
-	 */
-
-	if (pointer != NULL) {
-		gdk_device_ungrab (pointer, GDK_CURRENT_TIME);
-	}
-
-	
-	if (keyboard != NULL) {
-		gdk_device_ungrab (keyboard, GDK_CURRENT_TIME);
-	}
-
-	/* Stop the event because we don't want anyone else dealing with it. */	
-	gdk_flush ();
-	g_signal_stop_emission_by_name (canvas_container, "middle-click");
-
-	/* build an X event to represent the middle click. */
-	x_event.type = ButtonPress;
-	x_event.send_event = True;
-	x_event.display = GDK_DISPLAY_XDISPLAY (gdk_display_get_default ());
-	x_event.window = GDK_ROOT_WINDOW ();
-	x_event.root = GDK_ROOT_WINDOW ();
-	x_event.subwindow = 0;
-	x_event.time = event->time;
-	x_event.x = event->x;
-	x_event.y = event->y;
-	x_event.x_root = event->x_root;
-	x_event.y_root = event->y_root;
-	x_event.state = event->state;
-	x_event.button = event->button;
-	x_event.same_screen = True;
-	
-	/* Send it to the root window, the window manager will handle it. */
-	XSendEvent (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), GDK_ROOT_WINDOW (), True,
-		    ButtonPressMask, (XEvent *) &x_event);
-}
-
 static void
 unrealized_callback (GtkWidget *widget, NautilusDesktopCanvasView *desktop_canvas_view)
 {
@@ -417,6 +322,17 @@ realized_callback (GtkWidget *widget, NautilusDesktopCanvasView *desktop_canvas_
 			       desktop_canvas_view);
 }
 
+static void
+desktop_canvas_container_realize (GtkWidget *widget,
+				  NautilusDesktopCanvasView *desktop_canvas_view)
+{
+	GdkWindow *bin_window;
+	GdkRGBA transparent = { 0, 0, 0, 0 };
+
+	bin_window = gtk_layout_get_bin_window (GTK_LAYOUT (widget));
+	gdk_window_set_background_rgba (bin_window, &transparent);
+}
+
 static NautilusZoomLevel
 get_default_zoom_level (void)
 {
@@ -581,9 +497,10 @@ nautilus_desktop_canvas_view_init (NautilusDesktopCanvasView *desktop_canvas_vie
 
 	nautilus_view_set_show_foreign (NAUTILUS_VIEW (desktop_canvas_view),
 					FALSE);
-	
-	g_signal_connect_object (canvas_container, "middle-click",
-				 G_CALLBACK (nautilus_desktop_canvas_view_handle_middle_click), desktop_canvas_view, 0);
+
+	g_signal_connect_object (canvas_container, "realize",
+				 G_CALLBACK (desktop_canvas_container_realize), desktop_canvas_view, 0);
+
 	g_signal_connect_object (desktop_canvas_view, "realize",
 				 G_CALLBACK (realized_callback), desktop_canvas_view, 0);
 	g_signal_connect_object (desktop_canvas_view, "unrealize",
