@@ -136,6 +136,7 @@ static GParamSpec *properties[NUM_PROPERTIES] = { NULL, };
 static void nautilus_window_slot_force_reload (NautilusWindowSlot *slot);
 static void location_has_really_changed (NautilusWindowSlot *slot);
 static void nautilus_window_slot_connect_new_content_view (NautilusWindowSlot *slot);
+static void nautilus_window_slot_emit_location_change (NautilusWindowSlot *slot, GFile *from, GFile *to);
 
 static void
 nautilus_window_slot_sync_search_widgets (NautilusWindowSlot *slot)
@@ -694,6 +695,7 @@ nautilus_window_slot_open_location_full (NautilusWindowSlot *slot,
         NautilusWindowSlot *target_slot;
 	NautilusWindowOpenFlags slot_flags;
 	GFile *old_location;
+	GList *old_selection;
 	char *old_uri, *new_uri;
 	int new_slot_position;
 	gboolean use_same;
@@ -792,19 +794,24 @@ nautilus_window_slot_open_location_full (NautilusWindowSlot *slot,
 		}
 	}
 
-        if (target_window == window && target_slot == slot &&
+	old_selection = NULL;
+	if (slot->details->content_view != NULL) {
+		old_selection = nautilus_view_get_selection (slot->details->content_view);
+	}
+
+	if (target_window == window && target_slot == slot && !is_desktop &&
 	    old_location && g_file_equal (old_location, location) &&
-	    !is_desktop) {
+	    nautilus_file_selection_equal (old_selection, new_selection)) {
 
 		if (callback != NULL) {
 			callback (window, location, NULL, user_data);
 		}
 
 		goto done;
-        }
+	}
 
 	slot->details->pending_use_default_location = ((flags & NAUTILUS_WINDOW_OPEN_FLAG_USE_DEFAULT_LOCATION) != 0);
-        begin_location_change (target_slot, location, old_location, new_selection,
+	begin_location_change (target_slot, location, old_location, new_selection,
 			       NAUTILUS_LOCATION_CHANGE_STANDARD, 0, NULL, callback, user_data);
 
  done:
@@ -966,20 +973,26 @@ static void
 nautilus_window_slot_set_location (NautilusWindowSlot *slot,
 				   GFile *location)
 {
+	GFile *old_location;
+
 	if (slot->details->location &&
 	    g_file_equal (location, slot->details->location)) {
 		return;
 	}
 
-	if (slot->details->location) {
-		g_object_unref (slot->details->location);
-	}
+	old_location = slot->details->location;
 	slot->details->location = g_object_ref (location);
 
 	if (slot == nautilus_window_get_active_slot (slot->details->window)) {
 		nautilus_window_sync_location_widgets (slot->details->window);
 		nautilus_window_slot_update_title (slot);
 	}
+
+	nautilus_window_slot_emit_location_change (slot, old_location, location);
+
+	if (old_location) {
+		g_object_unref (old_location);
+	}
 }
 
 static void
@@ -2133,7 +2146,6 @@ nautilus_window_slot_update_for_new_location (NautilusWindowSlot *slot)
 	slot->details->viewed_file_in_trash = nautilus_file_is_in_trash (file);
         nautilus_file_unref (file);
 
-	nautilus_window_slot_emit_location_change (slot, old_location, new_location);
 	nautilus_window_slot_set_location (slot, new_location);
 
 	if (slot == nautilus_window_get_active_slot (window)) {
